summaryrefslogtreecommitdiff
path: root/distrib/mac68k/inst/install.sh
diff options
context:
space:
mode:
authorNiklas Hallqvist <niklas@cvs.openbsd.org>1996-04-25 21:32:17 +0000
committerNiklas Hallqvist <niklas@cvs.openbsd.org>1996-04-25 21:32:17 +0000
commitca20eee8a154b2ffc9df0940a63371bcd284aaed (patch)
tree2be4056cd94f078774d7c965c865f62e5289467a /distrib/mac68k/inst/install.sh
parentd44dfb5d692e3c38d987ca775af156909295c7b3 (diff)
Did some s/NetBSD/OpenBSD/, s/netbsd/bsd/ and $OpenBSD$ additions.
However this stuff is largely related to NetBSD and must be completely redone, if we will make real relases sometime
Diffstat (limited to 'distrib/mac68k/inst/install.sh')
-rw-r--r--distrib/mac68k/inst/install.sh15
1 files changed, 7 insertions, 8 deletions
diff --git a/distrib/mac68k/inst/install.sh b/distrib/mac68k/inst/install.sh
index 1eec1d88717..374038d661f 100644
--- a/distrib/mac68k/inst/install.sh
+++ b/distrib/mac68k/inst/install.sh
@@ -1,5 +1,5 @@
#!/bin/sh
-#
+# $OpenBSD: install.sh,v 1.2 1996/04/25 21:28:38 niklas Exp $
# $NetBSD: install.sh,v 1.1 1995/07/18 04:13:10 briggs Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
@@ -29,9 +29,8 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# NetBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.
@@ -95,9 +94,9 @@ prepdrive() {
esac
}
-echo "Welcome to the NetBSD ${VERSION} installation program."
+echo "Welcome to the OpenBSD ${VERSION} installation program."
echo ""
-echo "This program is designed to help you put NetBSD on your hard disk,"
+echo "This program is designed to help you put OpenBSD on your hard disk,"
echo "in a simple and rational way. Its main objective is to format,"
echo "mount and create an fstab for your root (/) and user (/usr)"
echo "partitions."
@@ -154,7 +153,7 @@ echo ""
echo "THIS IS YOUR LAST CHANCE!!!"
echo ""
echo "(answering yes will format your root partition on $rdev)"
-echo -n "Are you SURE you want NetBSD installed on your hard drive? (yes/no) "
+echo -n "Are you SURE you want OpenBSD installed on your hard drive? (yes/no) "
answer=""
while [ "$answer" = "" ]; do
getresp
@@ -258,11 +257,11 @@ echo " done."
echo ""
echo ""
echo "OK! The preliminary work of setting up your disk is now complete,"
-echo "and you can install the actual NetBSD software."
+echo "and you can install the actual OpenBSD software."
echo ""
echo "Right now, your root is mounted on /mnt and your usr on /mnt/usr."
echo "You should consult the installation notes to determine how to load"
-echo "and install the NetBSD distribution sets, and how to configure your"
+echo "and install the OpenBSD distribution sets, and how to configure your"
echo "system when you are done."
echo ""
echo "GOOD LUCK!"
@@ -29,9 +29,8 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
-# NetBSD installation script.
+# OpenBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.